@@ -717,6 +717,10 @@ void InitRemind(int argc, char const *argv[])
 		break;
 
 	    default:
+                if (tok.type == T_Illegal && tok.val < 0) {
+                    fprintf(stderr, "%s: `%s'\n", ErrMsg[-tok.val], arg);
+                    Usage();
+                }
 		Usage();
 	    }
 	}
@@ -1067,6 +1071,12 @@ ProcessLongOption(char const *arg)
         printf("%s\n", VERSION);
         exit(EXIT_SUCCESS);
     }
+    if (!strcmp(arg, "print-tokens")) {
+        print_remind_tokens();
+        print_builtinfunc_tokens();
+        print_sysvar_tokens();
+        exit(0);
+    }
     if (sscanf(arg, "max-execution-time=%d", &t) == 1) {
         if (t < 0) {
             fprintf(ErrFp, "%s: --max-execution-time must be non-negative\n", ArgV[0]);
@@ -1119,6 +1129,8 @@ guess_terminal_background(int *r, int *g, int *b)
 
     if (n != 8) {
         /* write failed... WTF?  Not much we can do */
+        tty_reset(ttyfd);
+        close(ttyfd);
         return;
     }
 
@@ -1142,6 +1154,7 @@ guess_terminal_background(int *r, int *g, int *b)
         return;
     }
     tty_reset(ttyfd);
+    close(ttyfd);
     buf[n+1] = 0;
     if (n < 25) {
         /* Too short */
